/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.plugin.loader;

import java.net.URL;
import java.util.List;

import org.tinygroup.fileresolver.FileProcessor;
import org.tinygroup.plugin.config.PluginInfo;

public interface PluginLoader {
	String PLUGIN_FOLDER = "plugins";
	String PLUGIN_FILENAME = "plugins.xml";

	List<PluginInfo> load(String path);

	/**
	 * 获取指定插件的ClassLoader
	 * 
	 * @param plugin
	 * @return
	 */
	ClassLoader getLoader(PluginInfo plugin);

	/**
	 * 获取插件外部包所在的ClassLoader，该Loader也是所有插件的ClassLoader的父Loader
	 * 
	 * @return
	 */
	ClassLoader getPublicLoader();

	/**
	 * 获取指定插件的资源扫描FileProcessor
	 * 
	 * @param plugin
	 * @return
	 */
	List<FileProcessor> getResourceProcessors(PluginInfo plugin);

	/**
	 * 获取指定插件的资源移除FileProcessor
	 * 
	 * @param plugin
	 * @return
	 */
	List<FileProcessor> getRemoveResourceProcessors(PluginInfo plugin);

	/**
	 * 删除指定插件的ClassLoader及相关Jar信息
	 * 
	 * @param plugin
	 */
	void remove(PluginInfo plugin);

	void add(PluginInfo plugin);

	List<PluginInfo> listJar(String path);

	void resolveResource(ClassLoader loader, URL urls1[]);

	void deResolveResource(ClassLoader loader, URL urls[]);
}
